@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for avahi
@@ -6,7 +8,7 @@ CVE checker for avahi
 https://www.cvedetails.com/product/7747/Avahi-Avahi.html?vendor_id=4481
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class AvahiChecker(Checker):
