@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for bash
@@ -6,7 +8,7 @@ CVE checker for bash
 https://www.cvedetails.com/vulnerability-list/vendor_id-72/product_id-21050/GNU-Bash.html
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class BashChecker(Checker):
