@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for bind
@@ -6,7 +8,7 @@ CVE checker for bind
 https://www.cvedetails.com/product/144/ISC-Bind.html?vendor_id=64
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class BindChecker(Checker):
