@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for cups
@@ -7,7 +9,7 @@ https://www.cvedetails.com/product/1219/Easy-Software-Products-Cups.html?vendor_
 
 """
 
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class CupsChecker(Checker):
