@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # !/usr/bin/env python3
 """
 CVE checker for Gstreamer
@@ -5,7 +8,7 @@ CVE checker for Gstreamer
 References:
 https://www.cvedetails.com/vulnerability-list/vendor_id-9481/Gstreamer.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class GstreamerChecker(Checker):
