@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for irssi
@@ -6,7 +8,7 @@ CVE checker for irssi
 https://www.cvedetails.com/product/2131/Irssi-Irssi.html?vendor_id=1229
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class IrssiChecker(Checker):
