@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for kerberos (CLI/library)
@@ -6,7 +8,7 @@ CVE checker for kerberos (CLI/library)
 References:
 https://www.cvedetails.com/vulnerability-list/vendor_id-42/product_id-61/MIT-Kerberos.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class KerberosChecker(Checker):
