@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for libcurl
@@ -11,7 +13,7 @@ RSS feed: http://www.cvedetails.com/vulnerability-feed.php?vendor_id=12682&produ
 
 Note: Some of the "first vulnerable in" data may not be entered correctly.
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibcurlChecker(Checker):
