@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for libvirt
@@ -6,7 +8,7 @@ CVE checker for libvirt
 https://www.cvedetails.com/product/15743/Libvirt-Libvirt.html?vendor_id=8917
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibvirtChecker(Checker):
