@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for mariadb CLI
@@ -9,7 +11,7 @@ https://www.cvedetails.com/vulnerability-list/vendor_id-12010/product_id-22503/M
 
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class MariadbChecker(Checker):
