@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for openldap
@@ -6,7 +8,7 @@ CVE checker for openldap
 https://www.cvedetails.com/product/755/Openldap-Openldap.html?vendor_id=439
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class OpenldapChecker(Checker):
