@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for openswan
@@ -6,7 +8,7 @@ CVE checker for openswan
 https://www.cvedetails.com/product/57217/Xelerance-Openswan.html?vendor_id=20146
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class OpenswanChecker(Checker):
