@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for openvpn
@@ -6,7 +8,7 @@ CVE checker for openvpn
 https://www.cvedetails.com/product/5768/Openvpn-Openvpn.html?vendor_id=3278
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class OpenvpnChecker(Checker):
