@@ -1,4 +1,6 @@
-#!/usr/bin/env python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 CVE checker for Python
 References:
@@ -8,8 +10,8 @@ https://www.cvedetails.com/vulnerability-list/vendor_id-10210/product_id-18230/P
 """
 import re
 
-from . import Checker
-from ..util import regex_find
+from cve_bin_tool.checkers import Checker
+from cve_bin_tool.util import regex_find
 
 
 class PythonChecker(Checker):
@@ -36,7 +38,7 @@ class PythonChecker(Checker):
             # we will update our regex to something more precise 3.6.d
             # where d is unknown and we will find d. which will return 3.6.9 or some other version
             version_pattern = [
-                rf"([{version_info['version'][0]}]+\.[{version_info['version'][2]}]+\.[0-9])"
+                rf"([{version_info['version'][0]}]+\.[{version_info['version'][2]}]+\.[0-9]+)"
             ]
             version_regex = list(map(re.compile, version_pattern))
             new_version = regex_find(lines, version_regex)
@@ -47,7 +49,6 @@ class PythonChecker(Checker):
         # else guess was unknown so we update our regex
         elif version_info:
             version_pattern = [
-                r"Version: ([23]+\.[0-9]+\.[0-9])+",
                 r"version: ([23]+\.[0-9]+\.[0-9])+",
                 r"Python ([23]+\.[0-9]+\.[0-9])+",
             ]
