@@ -1,10 +1,12 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for varnish
 https://www.cvedetails.com/vulnerability-list/vendor_id-12937/product_id-26407/Varnish-cache-Varnish.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class VarnishChecker(Checker):
