@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for wireshark
@@ -6,7 +8,7 @@ CVE checker for wireshark
 https://www.cvedetails.com/product/8292/Wireshark-Wireshark.html?vendor_id=4861
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class WiresharkChecker(Checker):
