@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for libxml2
@@ -9,7 +11,8 @@ http://www.cvedetails.com/vulnerability-list/vendor_id-1962/product_id-3311/Xmls
 RSS feed: http://www.cvedetails.com/vulnerability-feed.php?vendor_id=1962&product_id=3311&version_id=&orderby=2&cvssscoremin=0
 """
 import re
-from . import Checker
+
+from cve_bin_tool.checkers import Checker
 
 
 class Xml2Checker(Checker):
