@@ -1,6 +1,8 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 #!/usr/bin/python3
-# pylint: disable=invalid-name, useless-object-inheritance
-# useless-object-inheritance kept for python2 compatibility
+# pylint: disable=invalid-name
 
 """
 This tool scans for a number of common, vulnerable open source components
@@ -20,24 +22,26 @@ from collections import ChainMap
 from typing import Dict
 
 import pkg_resources
-from .output_engine import OutputEngine
 
-from .config import ConfigParser
-from .util import ProductInfo
-from .cve_scanner import CVEScanner
-from .cvedb import CVEDB, OLD_CACHE_DIR
-from .error_handler import (
-    excepthook,
-    ErrorHandler,
-    InsufficientArgs,
-    EmptyCache,
-    ErrorMode,
+from cve_bin_tool.config import ConfigParser
+from cve_bin_tool.cve_scanner import CVEScanner
+from cve_bin_tool.cvedb import CVEDB, OLD_CACHE_DIR
+from cve_bin_tool.error_handler import (
     CVEDataMissing,
+    EmptyCache,
+    ErrorHandler,
+    ErrorMode,
+    InsufficientArgs,
+    excepthook,
 )
-from .input_engine import InputEngine, TriageData
-from .log import LOGGER
-from .version import VERSION
-from .version_scanner import VersionScanner
+from cve_bin_tool.input_engine import InputEngine, TriageData
+from cve_bin_tool.log import LOGGER
+from cve_bin_tool.merge import MergeReports
+from cve_bin_tool.output_engine import OutputEngine
+from cve_bin_tool.package_list_parser import PackageListParser
+from cve_bin_tool.util import ProductInfo
+from cve_bin_tool.version import VERSION
+from cve_bin_tool.version_scanner import VersionScanner
 
 sys.excepthook = excepthook  # Always install excepthook for entrypoint module.
 
@@ -49,7 +53,7 @@ class StringToListAction(argparse.Action):
 
 
 def main(argv=None):
-    """ Scan a binary file for certain open source libraries that may have CVEs """
+    """Scan a binary file for certain open source libraries that may have CVEs"""
     argv = argv or sys.argv
 
     # Reset logger level to info
@@ -93,6 +97,9 @@ def main(argv=None):
     input_group.add_argument(
         "-C", "--config", action="store", default="", help="provide config file"
     )
+    input_group.add_argument(
+        "-L", "--package-list", action="store", default="", help="provide package list"
+    )
 
     output_group = parser.add_argument_group("Output")
     output_group.add_argument(
@@ -121,7 +128,7 @@ def main(argv=None):
         "-f",
         "--format",
         action="store",
-        choices=["csv", "json", "console", "html"],
+        choices=["csv", "json", "console", "html", "pdf"],
         help="update output format (default: console)",
     )
     output_group.add_argument(
@@ -137,6 +144,24 @@ def main(argv=None):
         choices=["low", "medium", "high", "critical"],
         help="minimum CVE severity to report (default: low)",
     )
+    output_group.add_argument(
+        "--report",
+        action="store_true",
+        help="Produces a report even if there are no CVE for the respective output format",
+    )
+    output_group.add_argument(
+        "-a",
+        "--append",
+        nargs="?",
+        const=True,
+        help="save output as intermediate report in json format",
+    )
+    output_group.add_argument(
+        "-t",
+        "--tag",
+        action="store",
+        help="add a unique tag to differentiate between multiple intermediate reports",
+    )
     parser.add_argument("-V", "--version", action="version", version=VERSION)
     parser.add_argument(
         "-u",
@@ -156,6 +181,12 @@ def main(argv=None):
         action="store_true",
         help="skips checking for a new version",
     )
+    parser.add_argument(
+        "-m",
+        "--merge",
+        action=StringToListAction,
+        help="comma separated intermediate reports path for merging",
+    )
 
     checker_group = parser.add_argument_group("Checkers")
     checker_group.add_argument(
@@ -190,6 +221,11 @@ def main(argv=None):
         "quiet": False,
         "output_file": "",
         "html_theme": "",
+        "report": False,
+        "package_list": "",
+        "append": False,
+        "tag": "",
+        "merge": None,
     }
 
     with ErrorHandler(mode=ErrorMode.NoTrace):
@@ -227,6 +263,28 @@ def main(argv=None):
                           """
         LOGGER.warning(warning_nolinux)
 
+    # CSVScanner related settings
+    score = 0
+    if args["severity"]:
+        # Set minimum CVSS score based on severity
+        cvss_score = {"low": 0, "medium": 4, "high": 7, "critical": 9}
+        score = cvss_score[args["severity"]]
+    if int(args["cvss"]) > 0:
+        score = int(args["cvss"])
+
+    merged_reports = None
+    if args["merge"]:
+        LOGGER.info(
+            "You can use -f --format and -o --output-file for saving merged intermediate reports in a file"
+        )
+        merged_reports = MergeReports(merge_files=args["merge"], score=score)
+        if args["input_file"]:
+            LOGGER.warning(
+                "Ignoring -i --input-file while merging intermediate reports"
+            )
+            args["input_file"] = None
+        merge_cve_scanner = merged_reports.merge_intermediate()
+
     # Database update related settings
     # Connect to the database
     cvedb_orig = CVEDB(
@@ -251,6 +309,7 @@ def main(argv=None):
         cvedb_orig.get_cvelist_if_stale()
     else:
         LOGGER.warning("Not verifying CVE DB cache")
+        cvedb_orig.get_db_update_date()
         if not cvedb_orig.nvd_years():
             with ErrorHandler(mode=error_mode, logger=LOGGER):
                 raise EmptyCache(cvedb_orig.cachedir)
@@ -260,14 +319,27 @@ def main(argv=None):
         with ErrorHandler(mode=error_mode, logger=LOGGER):
             raise CVEDataMissing("No data in CVE Database")
 
+    cvedb_orig.remove_cache_backup()
+
     # Input validation
-    if not args["directory"] and not args["input_file"]:
+    if (
+        not args["directory"]
+        and not args["input_file"]
+        and not args["package_list"]
+        and not args["merge"]
+    ):
         parser.print_usage()
         with ErrorHandler(logger=LOGGER, mode=ErrorMode.NoTrace):
             raise InsufficientArgs(
                 "Please specify a directory to scan or an input file required"
             )
 
+    # Output validation
+    if not args["append"] and args["tag"]:
+        LOGGER.warning(
+            f"Please specify -a --append to generate intermediate reports while using -t --tag"
+        )
+
     if args["directory"] and not os.path.exists(args["directory"]):
         parser.print_usage()
         with ErrorHandler(logger=LOGGER, mode=ErrorMode.NoTrace):
@@ -287,20 +359,21 @@ def main(argv=None):
             )
         )
 
-    # CSVScanner related settings
-    score = 0
-    if args["severity"]:
-        # Set minimum CVSS score based on severity
-        cvss_score = {"low": 0, "medium": 4, "high": 7, "critical": 9}
-        score = cvss_score[args["severity"]]
-    if int(args["cvss"]) > 0:
-        score = int(args["cvss"])
-
     with CVEScanner(score=score) as cve_scanner:
         triage_data: TriageData
         total_files: int = 0
         parsed_data: Dict[ProductInfo, TriageData] = {}
 
+        # Package List parsing
+        if args["package_list"]:
+            package_list = PackageListParser(
+                args["package_list"], error_mode=error_mode
+            )
+            parsed_data = package_list.parse_list()
+            for product_info, triage_data in parsed_data.items():
+                LOGGER.warning(f"{product_info}, {triage_data}")
+                cve_scanner.get_cves(product_info, triage_data)
+
         if args["input_file"]:
             input_engine = InputEngine(
                 args["input_file"], logger=LOGGER, error_mode=error_mode
@@ -328,12 +401,20 @@ def main(argv=None):
                     cve_scanner.get_cves(product_info, triage_data)
             total_files = version_scanner.total_scanned_files
 
+        if args["merge"]:
+            cve_scanner = merge_cve_scanner
+
         LOGGER.info("")
         LOGGER.info("Overall CVE summary: ")
-        LOGGER.info(
-            f"There are {cve_scanner.products_with_cve} products with known CVEs detected"
-        )
-        if cve_scanner.products_with_cve > 0:
+        if args["input_file"] or args["package_list"]:
+            LOGGER.info(
+                f"There are {cve_scanner.products_with_cve} products with known CVEs detected"
+            )
+        else:
+            LOGGER.info(
+                f"There are {cve_scanner.products_with_cve} files with known CVEs detected"
+            )
+        if cve_scanner.products_with_cve > 0 or args["report"]:
             affected_string = ", ".join(
                 map(
                     lambda product_version: "".join(str(product_version)),
@@ -348,9 +429,14 @@ def main(argv=None):
                 scanned_dir=args["directory"],
                 filename=args["output_file"],
                 themes_dir=args["html_theme"],
+                time_of_last_update=cvedb_orig.time_of_last_update,
+                tag=args["tag"],
                 products_with_cve=cve_scanner.products_with_cve,
                 products_without_cve=cve_scanner.products_without_cve,
                 total_files=total_files,
+                is_report=args["report"],
+                append=args["append"],
+                merge_report=merged_reports,
             )
 
             if not args["quiet"]:
