@@ -1,10 +1,13 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 #!/usr/bin/python3
 import os
 import sys
 
-from . import cli
-from .error_handler import excepthook, ErrorHandler, InsufficientArgs
-from .log import LOGGER
+from cve_bin_tool import cli
+from cve_bin_tool.error_handler import ErrorHandler, InsufficientArgs, excepthook
+from cve_bin_tool.log import LOGGER
 
 sys.excepthook = excepthook
 
