@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 Retrieval access and caching of NIST CVE database
 """
@@ -17,21 +20,25 @@ import aiohttp
 from bs4 import BeautifulSoup
 from rich.progress import track
 
-from .async_utils import FileIO, GzipFile, run_coroutine
-from .error_handler import (
+from cve_bin_tool.async_utils import FileIO, GzipFile, RateLimiter, run_coroutine
+from cve_bin_tool.error_handler import (
     AttemptedToWriteOutsideCachedir,
-    SHAMismatch,
-    CVEDataForYearNotInCache,
     CVEDataForCurlVersionNotInCache,
+    CVEDataForYearNotInCache,
     ErrorHandler,
     ErrorMode,
+    NVDRateLimit,
+    SHAMismatch,
 )
-from .log import LOGGER
-from .version import check_latest_version
+from cve_bin_tool.log import LOGGER
+from cve_bin_tool.version import check_latest_version
 
 logging.basicConfig(level=logging.DEBUG)
 
 # database defaults
+DISK_LOCATION_BACKUP = os.path.join(
+    os.path.expanduser("~"), ".cache", "cve-bin-tool-backup"
+)
 DISK_LOCATION_DEFAULT = os.path.join(os.path.expanduser("~"), ".cache", "cve-bin-tool")
 DBNAME = "cve.db"
 OLD_CACHE_DIR = os.path.join(os.path.expanduser("~"), ".cache", "cvedb")
@@ -43,6 +50,7 @@ class CVEDB:
     """
 
     CACHEDIR = DISK_LOCATION_DEFAULT
+    BACKUPCACHEDIR = DISK_LOCATION_BACKUP
     FEED = "https://nvd.nist.gov/vuln/data-feeds"
     LOGGER = LOGGER.getChild("CVEDB")
     NVDCVE_FILENAME_TEMPLATE = "nvdcve-1.1-{}.json.gz"
@@ -55,12 +63,16 @@ class CVEDB:
         self,
         feed=None,
         cachedir=None,
+        backup_cachedir=None,
         version_check=True,
         session=None,
         error_mode=ErrorMode.TruncTrace,
     ):
         self.feed = feed if feed is not None else self.FEED
         self.cachedir = cachedir if cachedir is not None else self.CACHEDIR
+        self.backup_cachedir = (
+            backup_cachedir if backup_cachedir is not None else self.BACKUPCACHEDIR
+        )
         self.error_mode = error_mode
         # Will be true if refresh was successful
         self.was_updated = False
@@ -72,9 +84,27 @@ class CVEDB:
         self.dbpath = os.path.join(self.cachedir, DBNAME)
         self.connection = None
         self.session = session
+        self.cve_count = -1
+
+        if not os.path.exists(self.dbpath):
+            self.rollback_cache_backup()
+
+    def get_cve_count(self):
+        if self.cve_count == -1:
+            # Force update
+            self.check_cve_entries()
+        return self.cve_count
+
+    def get_db_update_date(self):
+        # last time when CVE data was updated
+        self.time_of_last_update = datetime.datetime.fromtimestamp(
+            os.path.getmtime(self.dbpath)
+        )
+        return os.path.getmtime(self.dbpath)
 
     async def getmeta(self, session, meta_url):
-        async with session.get(meta_url) as response:
+        async with await session.get(meta_url) as response:
+            response.raise_for_status()
             return (
                 meta_url.replace(".meta", ".json.gz"),
                 dict(
@@ -87,15 +117,16 @@ class CVEDB:
             )
 
     async def nist_scrape(self, session):
-        async with session.get(self.feed) as response:
+        async with await session.get(self.feed) as response:
+            response.raise_for_status()
             page = await response.text()
             json_meta_links = self.META_REGEX.findall(page)
             return dict(
                 await asyncio.gather(
-                    *[
+                    *(
                         self.getmeta(session, f"{self.META_LINK}{meta_url}")
                         for meta_url in json_meta_links
-                    ]
+                    )
                 )
             )
 
@@ -130,12 +161,20 @@ class CVEDB:
                 self.LOGGER.debug(f"Correct SHA for {filename}")
                 return
         self.LOGGER.debug(f"Updating CVE cache for {filename}")
-        async with session.get(url) as response:
+        async with await session.get(url) as response:
+            # Raise better error message on ratelimit by NVD
+            if response.status == 403:
+                with ErrorHandler(mode=self.error_mode, logger=self.LOGGER):
+                    raise NVDRateLimit(
+                        f"{url} : download failed, you may have been rate limited."
+                    )
+            # Raise for all other 4xx errors
+            response.raise_for_status()
             gzip_data = await response.read()
-            json_data = gzip.decompress(gzip_data)
-            gotsha = hashlib.sha256(json_data).hexdigest().upper()
-            async with FileIO(filepath, "wb") as filepath_handle:
-                await filepath_handle.write(gzip_data)
+        json_data = gzip.decompress(gzip_data)
+        gotsha = hashlib.sha256(json_data).hexdigest().upper()
+        async with FileIO(filepath, "wb") as filepath_handle:
+            await filepath_handle.write(gzip_data)
         # Raise error if there was an issue with the sha
         if gotsha != sha:
             # Remove the file if there was an issue
@@ -147,17 +186,19 @@ class CVEDB:
     @staticmethod
     async def get_curl_versions(session):
         regex = re.compile(r"vuln-(\d+.\d+.\d+)\.html")
-        async with session.get(
+        async with await session.get(
             "https://curl.haxx.se/docs/vulnerabilities.html"
         ) as response:
+            response.raise_for_status()
             html = await response.text()
         matches = regex.finditer(html)
         return [match.group(1) for match in matches]
 
     async def download_curl_version(self, session, version):
-        async with session.get(
+        async with await session.get(
             f"https://curl.haxx.se/docs/vuln-{version}.html"
         ) as response:
+            response.raise_for_status()
             html = await response.text()
         soup = BeautifulSoup(html, "html.parser")
         table = soup.find("table")
@@ -181,7 +222,7 @@ class CVEDB:
             await f.write(json.dumps(json_data, indent=4))
 
     async def refresh(self):
-        """ Refresh the cve database and check for new version. """
+        """Refresh the cve database and check for new version."""
         # refresh the database
         if not os.path.isdir(self.cachedir):
             os.makedirs(self.cachedir)
@@ -190,13 +231,17 @@ class CVEDB:
             self.LOGGER.info("Checking if there is a newer version.")
             check_latest_version()
         if not self.session:
-            self.session = aiohttp.ClientSession(trust_env=True)
+            connector = aiohttp.TCPConnector(limit_per_host=19)
+            self.session = RateLimiter(
+                aiohttp.ClientSession(connector=connector, trust_env=True)
+            )
         self.LOGGER.info("Downloading CVE data...")
         nvd_metadata, curl_metadata = await asyncio.gather(
-            self.nist_scrape(self.session), self.get_curl_versions(self.session)
+            asyncio.ensure_future(self.nist_scrape(self.session)),
+            asyncio.ensure_future(self.get_curl_versions(self.session)),
         )
         tasks = [
-            self.cache_update(self.session, url, meta["sha256"])
+            asyncio.ensure_future(self.cache_update(self.session, url, meta["sha256"]))
             for url, meta in nvd_metadata.items()
             if meta is not None
         ]
@@ -207,10 +252,12 @@ class CVEDB:
         # each version) have been downloaded
         tasks.append(
             asyncio.gather(
-                *[
-                    self.download_curl_version(self.session, version)
+                *(
+                    asyncio.ensure_future(
+                        self.download_curl_version(self.session, version)
+                    )
                     for version in curl_metadata
-                ]
+                )
             )
         )
         total_tasks = len(tasks)
@@ -249,13 +296,17 @@ class CVEDB:
             - datetime.datetime.fromtimestamp(os.path.getmtime(self.dbpath))
         ) > datetime.timedelta(hours=24):
             self.refresh_cache_and_update_db()
+            self.time_of_last_update = datetime.datetime.today()
         else:
+            self.time_of_last_update = datetime.datetime.fromtimestamp(
+                os.path.getmtime(self.dbpath)
+            )
             self.LOGGER.info(
                 "Using cached CVE data (<24h old). Use -u now to update immediately."
             )
 
     def latest_schema(self, cursor):
-        """ Check database is using latest schema """
+        """Check database is using latest schema"""
         self.LOGGER.info("Check database is using latest schema")
         schema_check = "SELECT * FROM cve_severity WHERE 1=0"
         result = cursor.execute(schema_check)
@@ -267,7 +318,7 @@ class CVEDB:
         return schema_latest
 
     def check_cve_entries(self):
-        """ Report if database has some CVE entries """
+        """Report if database has some CVE entries"""
         self.db_open()
         cursor = self.connection.cursor()
         cve_entries_check = "SELECT COUNT(*) FROM cve_severity"
@@ -276,10 +327,11 @@ class CVEDB:
         cve_entries = cursor.fetchone()[0]
         self.LOGGER.info(f"There are {cve_entries} CVE entries in the database")
         self.db_close()
+        self.cve_count = cve_entries
         return cve_entries > 0
 
     def init_database(self):
-        """ Initialize db tables used for storing cve/version data """
+        """Initialize db tables used for storing cve/version data"""
         self.db_open()
         cursor = self.connection.cursor()
         cve_data_create = """
@@ -545,12 +597,10 @@ class CVEDB:
         Return the years we have NVD data for.
         """
         return sorted(
-            [
-                int(filename.split(".")[-3].split("-")[-1])
-                for filename in glob.glob(
-                    os.path.join(self.cachedir, "nvdcve-1.1-*.json.gz")
-                )
-            ]
+            int(filename.split(".")[-3].split("-")[-1])
+            for filename in glob.glob(
+                os.path.join(self.cachedir, "nvdcve-1.1-*.json.gz")
+            )
         )
 
     def load_curl_version(self, version):
@@ -583,8 +633,9 @@ class CVEDB:
         ]
 
     def clear_cached_data(self):
+        self.create_cache_backup()
         if os.path.exists(self.cachedir):
-            self.LOGGER.warning(f"Deleting cachedir {self.cachedir}")
+            self.LOGGER.warning(f"Updating cachedir {self.cachedir}")
             shutil.rmtree(self.cachedir)
         # Remove files associated with pre-1.0 development tree
         if os.path.exists(OLD_CACHE_DIR):
@@ -592,12 +643,38 @@ class CVEDB:
             shutil.rmtree(OLD_CACHE_DIR)
 
     def db_open(self):
-        """ Opens connection to sqlite database."""
+        """Opens connection to sqlite database."""
         if not self.connection:
             self.connection = sqlite3.connect(self.dbpath)
 
     def db_close(self):
-        """ Closes connection to sqlite database."""
+        """Closes connection to sqlite database."""
         if self.connection:
             self.connection.close()
             self.connection = None
+
+    def create_cache_backup(self):
+        """Creates a backup of the cachedir in case anything fails"""
+        if os.path.exists(self.cachedir):
+            self.LOGGER.debug(
+                f"Creating backup of cachedir {self.cachedir} at {self.backup_cachedir}"
+            )
+            self.remove_cache_backup()
+            shutil.copytree(self.cachedir, self.backup_cachedir)
+
+    def remove_cache_backup(self):
+        """Removes the backup if database was successfully loaded"""
+        if os.path.exists(self.backup_cachedir):
+            self.LOGGER.debug(f"Removing backup cache from {self.backup_cachedir}")
+            shutil.rmtree(self.backup_cachedir)
+
+    def rollback_cache_backup(self):
+        """Rollback the cachedir backup in case anything fails"""
+        if os.path.exists(os.path.join(self.backup_cachedir, DBNAME)):
+            self.LOGGER.info(f"Rolling back the cache to its previous state")
+            if os.path.exists(self.cachedir):
+                shutil.rmtree(self.cachedir)
+            shutil.move(self.backup_cachedir, self.cachedir)
+
+    def __del__(self):
+        self.rollback_cache_backup()
