@@ -1,4 +1,7 @@
-# pylint: disable=useless-object-inheritance, keyword-arg-before-vararg
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+# pylint: disable=keyword-arg-before-vararg
 # disabled for python2 compatibility reasons
 """
 Extraction of archives
@@ -9,21 +12,28 @@ import shutil
 import sys
 import tempfile
 
-from .async_utils import (
-    aio_unpack_archive,
-    aio_run_command,
-    aio_glob,
-    aio_inpath,
-    aio_rmdir,
-    aio_makedirs,
-    aio_mkdtemp,
+from rpmfile.cli import main as rpmextract
+
+from cve_bin_tool.async_utils import (
     ChangeDirContext,
     FileIO,
+    aio_glob,
+    aio_inpath,
+    aio_makedirs,
+    aio_mkdtemp,
+    aio_rmdir,
+    aio_run_command,
+    aio_unpack_archive,
+    async_wrap,
     run_coroutine,
 )
-from .error_handler import ExtractionFailed, UnknownArchiveType, ErrorHandler, ErrorMode
+
+from .error_handler import ErrorHandler, ErrorMode, ExtractionFailed, UnknownArchiveType
 from .log import LOGGER
 
+# Run rpmfile in a thread
+rpmextract = async_wrap(rpmextract)
+
 
 class BaseExtractor:
     """Extracts tar, rpm, etc. files"""
@@ -49,7 +59,7 @@ class BaseExtractor:
         }
 
     def can_extract(self, filename):
-        """ Check if the filename is something we know how to extract """
+        """Check if the filename is something we know how to extract"""
         for extension in itertools.chain(*self.file_extractors.values()):
             if filename.endswith(extension):
                 return True
@@ -57,19 +67,16 @@ class BaseExtractor:
 
     @staticmethod
     async def extract_file_tar(filename, extraction_path):
-        """ Extract tar files """
+        """Extract tar files"""
         with ErrorHandler(mode=ErrorMode.Ignore) as e:
             await aio_unpack_archive(filename, extraction_path)
         return e.exit_code
 
     async def extract_file_rpm(self, filename, extraction_path):
-        """ Extract rpm packages """
+        """Extract rpm packages"""
         if sys.platform.startswith("linux"):
             if not await aio_inpath("rpm2cpio") or not await aio_inpath("cpio"):
-                with ErrorHandler(mode=self.error_mode, logger=self.logger):
-                    raise Exception(
-                        "'rpm2cpio' and 'cpio' are required to extract rpm files"
-                    )
+                await rpmextract("-xC", extraction_path, filename)
             else:
                 stdout, stderr = await aio_run_command(["rpm2cpio", filename])
                 if stderr or not stdout:
@@ -99,7 +106,7 @@ class BaseExtractor:
         return 0
 
     async def extract_file_deb(self, filename, extraction_path):
-        """ Extract debian packages """
+        """Extract debian packages"""
         if not await aio_inpath("ar"):
             with ErrorHandler(mode=self.error_mode, logger=self.logger):
                 raise Exception("'ar' is required to extract deb files")
@@ -114,7 +121,7 @@ class BaseExtractor:
 
     @staticmethod
     async def extract_file_cab(filename, extraction_path):
-        """ Extract cab files """
+        """Extract cab files"""
         if sys.platform.startswith("linux"):
             if not await aio_inpath("cabextract"):
                 raise Exception("'cabextract' is required to extract cab files")
@@ -126,7 +133,7 @@ class BaseExtractor:
                     return 1
         else:
             stdout, stderr = await aio_run_command(
-                ["Expand", filename, "-F:*", extraction_path]
+                ["Expand", filename, "-R -F:*", extraction_path]
             )
             if stderr or not stdout:
                 return 1
@@ -134,7 +141,7 @@ class BaseExtractor:
 
     @staticmethod
     async def extract_file_zip(filename, extraction_path):
-        """ Extract zip files """
+        """Extract zip files"""
         if await aio_inpath("unzip"):
             stdout, stderr = await aio_run_command(
                 ["unzip", "-n", "-d", extraction_path, filename]
@@ -161,7 +168,7 @@ class TempDirExtractorContext(BaseExtractor):
         self.raise_failure = raise_failure
 
     async def aio_extract(self, filename):
-        """ Run the extractor """
+        """Run the extractor"""
         # Resolve path in case of cwd change
         filename = os.path.abspath(filename)
         for extractor in self.file_extractors:
@@ -191,12 +198,12 @@ class TempDirExtractorContext(BaseExtractor):
             raise UnknownArchiveType(filename)
 
     async def __aenter__(self):
-        """ Create a temporary directory to extract files to. """
+        """Create a temporary directory to extract files to."""
         self.tempdir = await aio_mkdtemp(prefix="cve-bin-tool-")
         return self
 
     async def __aexit__(self, exc_type, exc, exc_tb):
-        """ Removes all extraction directories that need to be cleaned up."""
+        """Removes all extraction directories that need to be cleaned up."""
         # removing directory can raise exception so wrap it around ErrorHandler.
         with ErrorHandler(mode=self.error_mode, logger=self.logger):
             await aio_rmdir(self.tempdir)
