@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 #!/usr/bin/python3
 
 """
@@ -6,7 +9,7 @@ the tool is able to support other operating systems like Windows
 and MacOS.
 """
 
-from .async_utils import FileIO, run_coroutine
+from cve_bin_tool.async_utils import FileIO, run_coroutine
 
 
 class Strings:
