@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # pylint: disable=too-many-arguments
 """ Utility classes for the CVE Binary Tool """
 import fnmatch
@@ -51,6 +54,8 @@ class CVE(NamedTuple):
     remarks: Remarks = Remarks.NewFound
     description: str = ""
     comments: str = ""
+    score: float = 0
+    cvss_version: int = 0
 
 
 class ProductInfo(NamedTuple):
@@ -70,7 +75,7 @@ class CVEData(defaultdict):
         return self[key]
 
 
-def regex_find(lines, version_patterns):
+def regex_find(lines, version_patterns) -> str:
     """Search a set of lines to find a match for the given regex"""
     new_guess = ""
 
@@ -88,7 +93,7 @@ def regex_find(lines, version_patterns):
         return "UNKNOWN"
 
 
-def inpath(binary):
+def inpath(binary) -> bool:
     """Check to see if something is available in the path.
     Used to check if dependencies are installed before use."""
     if sys.platform == "win32":
@@ -120,13 +125,13 @@ class DirWalk:
 
     def __init__(
         self,
-        pattern="*",
-        folder_include_pattern="*",
-        folder_exclude_pattern=".git",
-        file_exclude_pattern="",
-        yield_files=True,
-        yield_folders=False,
-    ):
+        pattern: str = "*",
+        folder_include_pattern: str = "*",
+        folder_exclude_pattern: str = ".git",
+        file_exclude_pattern: str = "",
+        yield_files: bool = True,
+        yield_folders: bool = False,
+    ) -> None:
         """
         Generator for walking the file system and filtering the results.
         """
@@ -138,7 +143,7 @@ class DirWalk:
         self.yield_folders = yield_folders
 
     def walk(self, roots=None):
-        """ Walk the directory looking for files matching the pattern """
+        """Walk the directory looking for files matching the pattern"""
         if roots is None:
             roots = []
         for root in roots:
@@ -174,8 +179,8 @@ class DirWalk:
                         yield os.path.normpath(os.path.join(dirpath, dirname))
 
     @staticmethod
-    def pattern_match(text, patterns):
-        """ Match filename patterns """
+    def pattern_match(text: str, patterns: str) -> bool:
+        """Match filename patterns"""
         if not patterns:
             return False
         for pattern in patterns.split(";"):
