@@ -1,18 +1,22 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import json
 import textwrap
 from urllib import request
+
 from packaging import version
 
 from cve_bin_tool.log import LOGGER
 
-VERSION = "2.1"
+VERSION: str = "2.2"
 
 
 def check_latest_version():
     """Checks for the latest version available at PyPI."""
 
-    name = "cve-bin-tool"
-    url = f"https://pypi.org/pypi/{name}/json"
+    name: str = "cve-bin-tool"
+    url: str = f"https://pypi.org/pypi/{name}/json"
     try:
         with request.urlopen(url) as resp:
             package_json = json.load(resp)
@@ -30,12 +34,15 @@ def check_latest_version():
                     )
                 )
             else:
-                # TODO In future mark me with some color ( prefer yellow or red )
                 LOGGER.info(
-                    f"You are running version {VERSION} of {name} but the latest PyPI Version is {pypi_version}."
+                    f"[bold red]You are running version {VERSION} of {name} but the latest PyPI Version is {pypi_version}.[/]",
+                    extra={"markup": True},
                 )
                 if version.parse(VERSION) < version.parse(pypi_version):
-                    LOGGER.info("Alert: We recommend using the latest stable release.")
+                    LOGGER.info(
+                        "[bold yellow]Alert: We recommend using the latest stable release.[/]",
+                        extra={"markup": True},
+                    )
     except Exception as error:
         LOGGER.warning(
             textwrap.dedent(
