@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 CVE-bin-tool CLI tests
 """
@@ -6,6 +9,15 @@ import logging
 import os
 import tempfile
 import unittest
+from test.utils import (
+    CURL_7_20_0_RPM,
+    CURL_7_20_0_URL,
+    LONG_TESTS,
+    TMUX_DEB,
+    TMUX_DEB_NAME,
+    TempDirTest,
+    download_file,
+)
 
 import pytest
 
@@ -13,19 +25,10 @@ from cve_bin_tool.cli import main
 from cve_bin_tool.cvedb import DISK_LOCATION_DEFAULT
 from cve_bin_tool.extractor import Extractor
 from cve_bin_tool.version_scanner import VersionScanner
-from .utils import (
-    TempDirTest,
-    download_file,
-    CURL_7_20_0_RPM,
-    CURL_7_20_0_URL,
-    TMUX_DEB_NAME,
-    TMUX_DEB,
-    LONG_TESTS,
-)
 
 
 class TestCLI(TempDirTest):
-    """ Tests the CVE Bin Tool CLI"""
+    """Tests the CVE Bin Tool CLI"""
 
     TEST_PATH = os.path.abspath(os.path.dirname(__file__))
 
@@ -38,7 +41,7 @@ class TestCLI(TempDirTest):
         assert main(["cve-bin-tool", "-l", "debug", "-x", self.tempdir]) != 0
 
     def test_binary_curl_7_20_0(self):
-        """ Extracting from rpm and scanning curl-7.20.0 """
+        """Extracting from rpm and scanning curl-7.20.0"""
         with Extractor() as ectx:
             extracted_path = ectx.extract(os.path.join(self.tempdir, CURL_7_20_0_RPM))
             assert (
@@ -54,11 +57,11 @@ class TestCLI(TempDirTest):
             )
 
     def test_no_extraction(self):
-        """ Test scanner against curl-7.20.0 rpm with extraction turned off """
+        """Test scanner against curl-7.20.0 rpm with extraction turned off"""
         assert main(["cve-bin-tool", os.path.join(self.tempdir, CURL_7_20_0_RPM)]) != 0
 
     def test_exclude(self, caplog):
-        """ Test that the exclude paths are not scanned """
+        """Test that the exclude paths are not scanned"""
         test_path = os.path.abspath(os.path.dirname(__file__))
         exclude_path = os.path.join(test_path, "assets/")
         checkers = list(VersionScanner().checkers.keys())
@@ -67,13 +70,13 @@ class TestCLI(TempDirTest):
         self.check_exclude_log(caplog, exclude_path, checkers)
 
     def test_usage(self):
-        """ Test that the usage returns 0 """
+        """Test that the usage returns 0"""
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool"])
         assert e.value.args[0] == -6
 
     def test_invalid_file_or_directory(self):
-        """ Test behaviour with an invalid file/directory """
+        """Test behaviour with an invalid file/directory"""
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "non-existant"])
         assert e.value.args[0] == -3
@@ -203,7 +206,7 @@ class TestCLI(TempDirTest):
         assert (
             "cve_bin_tool.CVEDB",
             logging.WARNING,
-            f"Deleting cachedir {db_path}",
+            f"Updating cachedir {db_path}",
         ) in caplog.record_tuples and (
             "cve_bin_tool.CVEDB",
             logging.INFO,
@@ -221,7 +224,7 @@ class TestCLI(TempDirTest):
         caplog.clear()
 
     def test_unknown_warning(self, caplog):
-        """ Test that an "UNKNOWN" file generates a warning """
+        """Test that an "UNKNOWN" file generates a warning"""
 
         # build the unknown test file in test/binaries
         with tempfile.NamedTemporaryFile(
@@ -250,7 +253,7 @@ class TestCLI(TempDirTest):
         assert f"png was detected with version UNKNOWN in file {filename}" in warnings
 
     def test_quiet_mode(self, capsys, caplog):
-        """ Test that an quite mode isn't generating any output """
+        """Test that an quite mode isn't generating any output"""
 
         with tempfile.NamedTemporaryFile(
             "w+b", suffix="strong-swan-4.6.3.out", delete=False
