@@ -1,14 +1,17 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import asyncio
 import datetime
 import shutil
 import sys
 import tempfile
+from test.utils import event_loop
 
 import aiohttp
 import pytest
 
 from cve_bin_tool.cvedb import CVEDB
-from .utils import event_loop
 
 
 class TestCVEDB:
@@ -22,7 +25,10 @@ class TestCVEDB:
 
     @pytest.mark.asyncio
     async def test_00_getmeta(self):
-        async with aiohttp.ClientSession(trust_env=True) as session:
+        connector = aiohttp.TCPConnector(limit_per_host=19)
+        async with aiohttp.ClientSession(
+            connector=connector, trust_env=True
+        ) as session:
             _jsonurl, meta = await self.cvedb.getmeta(
                 session,
                 "https://nvd.nist.gov/feeds/json/cve/1.1/nvdcve-1.1-modified.meta",
