@@ -1,20 +1,33 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 __all__ = [
+    "accountsservice",
     "avahi",
     "bash",
     "bind",
     "binutils",
+    "bolt",
+    "bubblewrap",
     "busybox",
     "bzip2",
+    "cryptsetup",
     "cups",
     "curl",
+    "dnsmasq",
     "dovecot",
+    "dpkg",
+    "enscript",
     "expat",
     "ffmpeg",
     "freeradius",
+    "ftp",
     "gcc",
     "gimp",
     "glibc",
+    "gnupg",
     "gnutls",
+    "gpgme",
     "gstreamer",
     "haproxy",
     "hostapd",
@@ -28,7 +41,12 @@ __all__ = [
     "libdb",
     "libgcrypt",
     "libjpeg-turbo",
+    "libsndfile",
+    "libsoup",
+    "libssh2",
     "libvirt",
+    "libxslt",
+    "logrotate",
     "mariadb",
     "memcached",
     "mysql",
@@ -40,15 +58,19 @@ __all__ = [
     "nessus",
     "nginx",
     "node",
+    "ntp",
     "openafs",
+    "openjpeg",
     "openldap",
     "openssh",
     "openssl",
     "openswan",
     "openvpn",
+    "p7zip",
     "png",
     "polarssl",
     "postgresql",
+    "pspp",
     "python",
     "qt",
     "radare2",
@@ -61,7 +83,9 @@ __all__ = [
     "systemd",
     "tcpdump",
     "varnish",
+    "webkitgtk",
     "wireshark",
+    "wpa_supplicant",
     "xerces",
     "xml2",
     "zlib",
