@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "bind", "version": "9.10.2", "version_strings": ["BIND 9.10.2"]}
 ]
@@ -9,9 +12,9 @@ package_test_data = [
         "version": "9.10.3",
     },
     {
-        "url": "http://mirror.centos.org/centos/6/os/x86_64/Packages/",
-        "package_name": "bind-9.8.2-0.68.rc1.el6.x86_64.rpm",
+        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
+        "package_name": "bind-9.11.4-26.P2.el7.x86_64.rpm",
         "product": "bind",
-        "version": "9.8.2",
+        "version": "9.11.4",
     },
 ]
