@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "gstreamer",
@@ -16,8 +19,8 @@ package_test_data = [
         "version": "1.0",
     },
     {
-        "url": "http://mirror.centos.org/centos/6/os/x86_64/Packages/",
-        "package_name": "gstreamer-0.10.29-1.el6.x86_64.rpm",
+        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
+        "package_name": "gstreamer-0.10.36-7.el7.i686.rpm",
         "product": "gstreamer",
         "version": "0.10",
     },
