@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "libvirt",
@@ -11,11 +14,5 @@ package_test_data = [
         "package_name": "libvirt-client-1.2.2-1.fc21.x86_64.rpm",
         "product": "libvirt",
         "version": "1.2.2",
-    },
-    {
-        "url": "https://mirrors.kernel.org/mageia/distrib/4/x86_64/media/core/release/",
-        "package_name": "libvirt-utils-1.2.1-1.mga4.x86_64.rpm",
-        "product": "libvirt",
-        "version": "1.2.1",
-    },
+    }
 ]
