@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "python",
@@ -28,9 +31,9 @@ package_test_data = [
         "version": "3.8.2",
     },
     {
-        "url": "https://rpmfind.net/linux/openmandriva/4.0/repository/x86_64/main/release/",
-        "package_name": "python-3.7.3-4-omv4000.x86_64.rpm",
+        "url": "https://download-ib01.fedoraproject.org/pub/fedora/linux/releases/33/Everything/aarch64/os/Packages/p/",
+        "package_name": "python3-3.9.0-1.fc33.aarch64.rpm",
         "product": "python",
-        "version": "3.7.3",
+        "version": "3.9.0",
     },
 ]
