@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "radare2", "version": "3.3.0", "version_strings": ["rafind2 v3.3.0"]}
 ]
@@ -7,11 +10,5 @@ package_test_data = [
         "package_name": "radare2-3.0.1-2.fc27.x86_64.rpm",
         "product": "radare2",
         "version": "3.0.1",
-    },
-    {
-        "url": "http://archive.ubuntu.com/ubuntu/pool/universe/r/radare2/",
-        "package_name": "radare2_3.2.1+dfsg-5build1_amd64.deb",
-        "product": "radare2",
-        "version": "3.2.1",
-    },
+    }
 ]
