@@ -1,74 +1,91 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 CVE-bin-tool OutputEngine tests
 """
 import csv
+import datetime
 import json
 import logging
 import os
 import tempfile
 import unittest
+from datetime import datetime
 
 from rich.console import Console
 
 from cve_bin_tool.output_engine import OutputEngine, output_csv, output_json
 from cve_bin_tool.output_engine.console import output_console
+from cve_bin_tool.output_engine.html import output_html
 from cve_bin_tool.output_engine.util import format_output
-from cve_bin_tool.util import ProductInfo, CVEData, CVE
+from cve_bin_tool.util import CVE, CVEData, ProductInfo
 
 
 class TestOutputEngine(unittest.TestCase):
-    """ Test the OutputEngine class functions """
+    """Test the OutputEngine class functions"""
 
     MOCK_OUTPUT = {
-        ProductInfo("vendorname0", "productname0", "1.0"): CVEData(
-            cves=[CVE("CVE-1234-1234", "MEDIUM"), CVE("CVE-1234-9876", "LOW")],
+        ProductInfo("vendor0", "product0", "1.0"): CVEData(
+            cves=[
+                CVE("CVE-1234-1234", "MEDIUM", score=4.2, cvss_version=2),
+                CVE("CVE-1234-1234", "LOW", score=1.2, cvss_version=2),
+            ],
             paths={""},
         ),
-        ProductInfo("vendorname0", "productname0", "2.8.6"): CVEData(
-            cves=[CVE("CVE-1234-1111", "LOW")], paths={""}
+        ProductInfo("vendor0", "product0", "2.8.6"): CVEData(
+            cves=[CVE("CVE-1234-1234", "LOW", score=2.5, cvss_version=3)], paths={""}
         ),
-        ProductInfo("vendorname1", "productname1", "3.2.1.0"): CVEData(
-            cves=[CVE("CVE-1234-5678", "HIGH")], paths={""}
+        ProductInfo("vendor1", "product1", "3.2.1.0"): CVEData(
+            cves=[CVE("CVE-1234-1234", "HIGH", score=7.5, cvss_version=2)], paths={""}
         ),
     }
 
     FORMATTED_OUTPUT = [
         {
-            "vendor": "vendorname0",
-            "product": "productname0",
+            "vendor": "vendor0",
+            "product": "product0",
             "version": "1.0",
             "cve_number": "CVE-1234-1234",
             "severity": "MEDIUM",
+            "score": "4.2",
+            "cvss_version": "2",
             "paths": "",
             "remarks": "NewFound",
             "comments": "",
         },
         {
-            "vendor": "vendorname0",
-            "product": "productname0",
+            "vendor": "vendor0",
+            "product": "product0",
             "version": "1.0",
-            "cve_number": "CVE-1234-9876",
+            "cve_number": "CVE-1234-1234",
             "severity": "LOW",
+            "score": "1.2",
+            "cvss_version": "2",
             "paths": "",
             "remarks": "NewFound",
             "comments": "",
         },
         {
-            "vendor": "vendorname0",
-            "product": "productname0",
+            "vendor": "vendor0",
+            "product": "product0",
             "version": "2.8.6",
-            "cve_number": "CVE-1234-1111",
+            "cve_number": "CVE-1234-1234",
             "severity": "LOW",
+            "score": "2.5",
+            "cvss_version": "3",
             "paths": "",
             "remarks": "NewFound",
             "comments": "",
         },
         {
-            "vendor": "vendorname1",
-            "product": "productname1",
+            "vendor": "vendor1",
+            "product": "product1",
             "version": "3.2.1.0",
-            "cve_number": "CVE-1234-5678",
+            "cve_number": "CVE-1234-1234",
             "severity": "HIGH",
+            "score": "7.5",
+            "cvss_version": "2",
             "paths": "",
             "remarks": "NewFound",
             "comments": "",
@@ -77,7 +94,12 @@ class TestOutputEngine(unittest.TestCase):
 
     def setUp(self) -> None:
         self.output_engine = OutputEngine(
-            all_cve_data=self.MOCK_OUTPUT, scanned_dir="", filename="", themes_dir=""
+            all_cve_data=self.MOCK_OUTPUT,
+            scanned_dir="",
+            filename="",
+            themes_dir="",
+            time_of_last_update=datetime.today(),
+            tag="",
         )
         self.mock_file = tempfile.NamedTemporaryFile("w+", encoding="utf-8")
 
@@ -85,17 +107,17 @@ class TestOutputEngine(unittest.TestCase):
         self.mock_file.close()
 
     def test_formatted_output(self):
-        """ Test reformatting products """
+        """Test reformatting products"""
         self.assertEqual(format_output(self.MOCK_OUTPUT), self.FORMATTED_OUTPUT)
 
     def test_output_json(self):
-        """ Test formatting output as JSON """
+        """Test formatting output as JSON"""
         output_json(self.MOCK_OUTPUT, self.mock_file)
         self.mock_file.seek(0)  # reset file position
         self.assertEqual(json.load(self.mock_file), self.FORMATTED_OUTPUT)
 
     def test_output_csv(self):
-        """ Test formatting output as CSV """
+        """Test formatting output as CSV"""
         output_csv(self.MOCK_OUTPUT, self.mock_file)
         self.mock_file.seek(0)  # reset file position
         reader = csv.DictReader(self.mock_file)
@@ -106,13 +128,89 @@ class TestOutputEngine(unittest.TestCase):
         """Test Formatting Output as console"""
 
         console = Console(file=self.mock_file)
-        output_console(self.MOCK_OUTPUT, console=console)
+        output_console(
+            self.MOCK_OUTPUT,
+            console=console,
+            time_of_last_update=datetime.today(),
+        )
 
-        expected_output = "│ vendorname0 │ productname0 │ 1.0     │ CVE-1234-1234 │ MEDIUM   │\n│ vendorname0 │ productname0 │ 1.0     │ CVE-1234-9876 │ LOW      │\n│ vendorname0 │ productname0 │ 2.8.6   │ CVE-1234-1111 │ LOW      │\n│ vendorname1 │ productname1 │ 3.2.1.0 │ CVE-1234-5678 │ HIGH     │\n└─────────────┴──────────────┴─────────┴───────────────┴──────────┘\n"
+        expected_output = "│ vendor0 │ product0 │ 1.0     │ CVE-1234-1234 │ MEDIUM   │ 4.2 (v2)             │\n│ vendor0 │ product0 │ 1.0     │ CVE-1234-1234 │ LOW      │ 1.2 (v2)             │\n│ vendor0 │ product0 │ 2.8.6   │ CVE-1234-1234 │ LOW      │ 2.5 (v3)             │\n│ vendor1 │ product1 │ 3.2.1.0 │ CVE-1234-1234 │ HIGH     │ 7.5 (v2)             │\n└─────────┴──────────┴─────────┴───────────────┴──────────┴──────────────────────┘\n"
         self.mock_file.seek(0)  # reset file position
         result = self.mock_file.read()
         self.assertIn(expected_output, result)
 
+    def test_output_html(self):
+        """ Test formatting output as HTML """
+
+        logger = logging.getLogger()
+
+        output_html(
+            self.MOCK_OUTPUT,
+            "",
+            "",
+            "",
+            3,
+            3,
+            0,
+            None,
+            logger,
+            self.mock_file,
+        )
+
+        # sample report
+        with open(
+            os.path.join(os.path.dirname(__file__), "sample_report", "html_report.html")
+        ) as report:
+            expected_output = report.read()
+            report.close()
+
+        ## Changing some dynamic data in html reports
+        # 1. date
+        # 2. div IDs (dynamic ones)
+
+        self.mock_file.seek(0)
+        result = self.mock_file.read()
+
+        result_lines = result.splitlines()
+
+        ## date
+        # date is replaced by {{date}} in the result
+        # The respective change is also made in the sample report
+
+        result = result.replace(datetime.now().strftime("%d %b %Y"), r"{{date}}")
+
+        ## div IDs
+        # div IDs, in the dashboard, which were created dynamically is being replaced by their respective line numbers
+        # The respective changes are also made in the sample report
+
+        # This signature is always a line or two before the dynamic data
+        signature = '<div class="card-body">'
+
+        for line_number in range(len(result_lines)):
+            if signature in result_lines[line_number]:
+
+                if "<!--" in result_lines[line_number + 1]:
+                    # Sometimes there is a comment line after the signature line, hence it's skipped
+                    line_number += 2
+                else:
+                    line_number += 1
+
+                line = result_lines[line_number]  # line with the dynamic data
+                index_div_id = line.index('<div id="') + len('<div id="')
+                div_id = ""  # div ID of the dynamic part
+
+                char = line[index_div_id]
+                while char != '"':
+                    div_id += char
+                    index_div_id += 1
+                    char = line[index_div_id]
+
+                result = result.replace(
+                    div_id, f"{line_number+1}"
+                )  # div IDs replaced with line numbers
+
+        assert expected_output, result
+
     def test_output_file(self):
         """Test file generation logic in output_file"""
         logger = logging.getLogger()
