@@ -1,19 +1,22 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """
 CVE-bin-tool Strings tests
 """
 import os
+from test.utils import event_loop
 
 import pytest
 
 from cve_bin_tool.async_utils import aio_run_command
 from cve_bin_tool.strings import Strings
-from .utils import event_loop
 
 ASSETS_PATH = os.path.join(os.path.abspath(os.path.dirname(__file__)), "assets")
 
 
 class TestStrings:
-    """ Tests the CVE Bin Tool Strings"""
+    """Tests the CVE Bin Tool Strings"""
 
     @classmethod
     def setup_class(cls):
